@@ -14,7 +14,6 @@ class PDF::Catalog
     # see [PDF 1.7 TABLE 3.25 Entries in the catalog dictionary]
     use PDF::DAO::Tie;
     use PDF::DAO::Tie::Hash;
-    use PDF::DAO::Array;
     use PDF::DAO::Dict;
     use PDF::DAO::Name;
     use PDF::DAO::Null;
@@ -49,12 +48,12 @@ class PDF::Catalog
     my subset Outlines of PDF::Class::Type where { .type eq 'Outlines' }; # autoloaded PDF::Outlines
     has Outlines $.Outlines is entry(:indirect); #| (Optional; must be an indirect reference) The outline dictionary that is the root of the document’s outline hierarchy
 
-    has PDF::DAO::Array $.Threads is entry(:indirect);        #| (Optional; PDF 1.1; must be an indirect reference) An array of thread dictionaries representing the document’s article threads
+    has PDF::DAO::Dict @.Threads is entry(:indirect);        #| (Optional; PDF 1.1; must be an indirect reference) An array of thread dictionaries representing the document’s article threads
 
     use PDF::Action :coerce;
     has PDF::Action::Destination $.OpenAction is entry(:&coerce);               #| (Optional; PDF 1.1) A value specifying a destination to be displayed or an action to be performed when the document is opened.
 
-    has PDF::DAO::Dict $.AA is entry;                    #| (Optional; PDF 1.4) An additional-actions dictionary defining the actions to be taken in response to various trigger events affecting the document as a whole
+    has PDF::DAO::Dict $.AA is entry(:alias<additional-actions>);                    #| (Optional; PDF 1.4) An additional-actions dictionary defining the actions to be taken in response to various trigger events affecting the document as a whole
 
     has PDF::DAO::Dict $.URI is entry;                   #| (Optional; PDF 1.1) A URI dictionary containing document-level information for URI
 
