@@ -37,10 +37,15 @@ class PDF::Page
     has Hash $.Group is entry;                   #| (Optional; PDF 1.4) A group attributes dictionary specifying the attributes of the page’s page group for use in the transparent imaging model
     has PDF::DAO::Stream $.Thumb is entry;       #| (Optional) A stream object defining the page’s thumbnail image
     has @.B is entry(:indirect, :alias<beads>);                 #| (Optional; PDF 1.1; recommended if the page contains article beads) An array of indirect references to article beads appearing on the page
-    has Numeric $.Dur is entry;                  #| (Optional; PDF 1.1) The page’s display duration (also called its advance timing): the maximum length of time, in seconds, that the page is displayed during presentations before the viewer application automatically advances to the next page
-    has Hash $.Trans is entry;                   #| (Optional; PDF 1.1) A transition dictionary describing the transition effect to be used when displaying the page during presentations
-    my subset Annot of Hash where { .<Type> ~~ 'Annot' }
-    has Annot @.Annots is entry; #| (Optional) An array of annotation dictionaries representing annotations associated with the page
+    has Numeric $.Dur is entry(:alias<display-duration>);       #| (Optional; PDF 1.1) The page’s display duration (also called its advance timing): the maximum length of time, in seconds, that the page is displayed during presentations before the viewer application automatically advances to the next page
+    has Hash $.Trans is entry(:alias<transition-effect>);       #| (Optional; PDF 1.1) A transition dictionary describing the transition effect to be used when displaying the page during presentations
+    use PDF::Field;
+    my subset Annot of Hash where { .<Type> ~~ 'Annot' && (! .<FT> || $_ ~~ PDF::Field) }
+    multi sub coerce($annot is rw, $_) {
+        PDF::DAO.coerce($annot, PDF::Field.field-delegate($annot))
+            if $annot<FT>:exists;
+    }
+    has Annot @.Annots is entry(:&coerce); #| (Optional) An array of annotation dictionaries representing annotations associated with the page
     use PDF::Action;
     has PDF::Action $.AA is entry(:alias<additional-actions>);                      #| (Optional; PDF 1.2) An additional-actions dictionary defining actions to be performed when the page is opened or closed
     has PDF::DAO::Stream $.Metadata is entry;    #| (Optional; PDF 1.4) A metadata stream containing metadata for the page
@@ -55,5 +60,23 @@ class PDF::Page
     has Numeric $.UserUnit is entry;             #| (Optional; PDF 1.6) A positive number giving the size of default user space units, in multiples of 1 ⁄ 72 inch
     has Hash @.VP is entry(:alias<view-ports>);  #| Optional; PDF 1.6) An array of viewport dictionaries
 
+    method fields {
+        my $annots = self.Annots;
+        $annots.keys.map({$annots[$_]}).grep({$_ ~~ PDF::Field})
+    }
+
+   method fields-hash( Array $fields-arr = self.fields,
+                       :$key where 'T'|'TU'|'TR' = 'T'
+			--> Hash) {
+	my %fields;
+
+	for $fields-arr.list -> $field {
+            %fields{ $_ } = $field
+		    with $field{$key};
+	}
+
+	%fields;
+    }
+
 }
 
